#!/usr/bin/env python

import pygame
import math
import random

use_sound = True
pygame.init()
#pygame.font.init()

try:
    pygame.mixer.init()
except:
    use_sound = False

screen = pygame.display.set_mode((864, 480))

font = pygame.font.Font("PhaistosDisk_-_Layne_Lighthouse.ttf", 24)

img = {}
img['background'] = pygame.image.load("background.png")
img['title'] = pygame.image.load("title.png")
img['end'] = pygame.image.load("end.png")
img['monster'] = pygame.image.load("monster.png").convert_alpha()
img['woman'] = pygame.image.load("woman.png").convert_alpha()
img['strike'] = pygame.image.load("strike.png").convert_alpha()
img['hurt'] = pygame.image.load("hurt.png").convert_alpha()
img['miss'] = pygame.image.load("miss.png").convert_alpha()

snd = {}
if use_sound:
    snd['hurt'] = pygame.mixer.Sound('hurt.wav')
    snd['strike'] = pygame.mixer.Sound('strike.wav')
    snd['woman_hurt'] = pygame.mixer.Sound('woman_hurt.wav')

class Door:
    def __init__(self, x):
        self.image = None
        self.type = 0
        self.countdown = 0
        self.x = x * 288
        
        self.strike_countdown = 0
        
    def update(self):
        if self.countdown > 0:
            self.countdown -= 1
            if self.countdown == 0:
                if self.type == 1:
                    if self.strike_countdown == 0:
                        get_hurt()
                self.image = None
                self.type = 0
        else:
            if random.random() < 0.01:
                self.type = random.randint(0, 2)
                if self.type > 0:
                    self.countdown = difficulty
                    self.strike_countdown = 0
                    
                if self.type == 1:
                    self.image = img['monster']
                elif self.type == 2:
                    self.image = img['woman']
                
        if self.strike_countdown > 0:
            self.strike_countdown -= 1
            if self.strike_countdown == 0:
                if self.type == 1:
                    update_score()
                elif self.type == 2:
                    hit_girl()
                self.image = None
                self.type = 0
                self.countdown = 0
        
    def draw(self, surf):
        if self.image is not None:
            surf.blit(self.image, (self.x, 0))
            
        if self.strike_countdown > 0:
            surf.blit(img['strike'], (self.x, 0))
            
    def strike(self):
        self.strike_countdown = 10
        if use_sound:
            snd['strike'].play()

def reset():
    global doors, hurt_counter, slashes, difficulty, misses, score, score_img, level_up
    doors = [Door(i) for i in xrange(3)]
    slashes = [0, 0, 0]
    hurt_counter = 0
    difficulty = 60
    misses = 0
    score = 0
    score_img = font.render("Ghouls: %i" % score, True, (255,255,255))
    level_up = 300

def get_hurt():
    global hurt_counter, misses
    hurt_counter = 10
    misses += 1
    if use_sound:
        snd['hurt'].play()
    
def hit_girl():
    global misses
    misses += 1
    if use_sound:
        snd['woman_hurt'].play()

def update_score():
    global score, score_img
    score += 1
    score_img = font.render("Ghouls: %i" % score, True, (255,255,255))

reset()

clock = pygame.time.Clock()
state = 1
while state != 0:
    key = pygame.key.get_pressed()
    if state == 1:
        # TITLE
        screen.blit(img['title'], (0,0))
        
    elif state == 2:
        # GAME
        level_up -= 1
        if level_up == 0:
            difficulty -= 2
            level_up = 300
            
        screen.blit(img['background'], (0,0))
        for i in xrange(3):
            if doors[i] is not None:
                doors[i].update()
                doors[i].draw(screen)
        
        if hurt_counter > 0:
            screen.blit(img['hurt'], (0,0))
            hurt_counter -= 1
            
        for i in xrange(misses):
            screen.blit(img['miss'], (864 - img['miss'].get_width() * (i+1), 0))
            
        screen.blit(score_img, (0,0))
        
        if misses >= 3:
            state = 3
        
    elif state == 3:
        # WIN
        screen.blit(img['end'], (0,0))
        screen.blit(score_img, (450, 250))
    
    elif state == 4:
        #LOSE
        pass
    
    clock.tick(60)
    pygame.display.flip()
    
    for event in pygame.event.get():
        if event.type == pygame.QUIT:
            state = 0
            
        if event.type == pygame.KEYDOWN:
            if event.key == pygame.K_SPACE:
                if state == 1:
                    state = 2
                
                if (state == 3) or (state == 4):
                    reset()
                    state = 1
                    
            if event.key == pygame.K_ESCAPE:
                state = 0
                
            if event.key == pygame.K_r:
                reset()
        
        if event.type == pygame.MOUSEBUTTONDOWN:
            if state == 2:
                if event.button == 1:
                    doors[event.pos[0]/288].strike()

pygame.quit()
